@@ -56,6 +56,15 @@ stringbuffer_init(stringbuffer_t *s)
 	stringbuffer_init_with_size(s, STRINGBUFFER_STARTSIZE);
 }
 
+void
+stringbuffer_init_varlena(stringbuffer_t *s)
+{
+	stringbuffer_init_with_size(s, STRINGBUFFER_STARTSIZE + LWVARHDRSZ);
+	/* Zero out LWVARHDRSZ bytes at the front of the buffer */
+	stringbuffer_append_len(s, "\0\0\0\0\0\0\0\0", LWVARHDRSZ);
+}
+
+
 /**
 * Allocate a new stringbuffer_t. Use stringbuffer_destroy to free.
 */
@@ -130,6 +139,14 @@ stringbuffer_getstringcopy(stringbuffer_t *s)
 	return str;
 }
 
+lwvarlena_t *
+stringbuffer_getvarlena(stringbuffer_t *s)
+{
+	lwvarlena_t *output = (lwvarlena_t *)(s->str_start);
+	LWSIZE_SET(output->size, (s->str_end - s->str_start));
+	return output;
+}
+
 lwvarlena_t *
 stringbuffer_getvarlenacopy(stringbuffer_t *s)
 {
@@ -176,6 +193,8 @@ stringbuffer_copy(stringbuffer_t *dst, stringbuffer_t *src)
 * check errno for reasons, documented in the printf man page.
 */
 static int
+stringbuffer_avprintf(stringbuffer_t *s, const char *fmt, va_list ap) __attribute__ ((format (printf, 2, 0)));
+static int
 stringbuffer_avprintf(stringbuffer_t *s, const char *fmt, va_list ap)
 {
 	int maxlen = (s->capacity - (s->str_end - s->str_start));
@@ -188,7 +207,7 @@ stringbuffer_avprintf(stringbuffer_t *s, const char *fmt, va_list ap)
 	len = vsnprintf(s->str_end, maxlen, fmt, ap2);
 	va_end(ap2);
 
-	/* Propogate errors up */
+	/* Propagate errors up */
 	if ( len < 0 )
 		#if defined(__MINGW64_VERSION_MAJOR)
 		va_copy(ap2, ap);
