@@ -560,6 +560,16 @@ gserialized_datum_get_box2df_p(Datum gsdatum, BOX2DF *box2df)
 		{
 			result = box2df_from_gbox_p(&gbox, box2df);
 		}
+		else {
+			/* Oh dear, has someone fed us an empty? */
+			POSTGIS_FREE_IF_COPY_P(gpart, gsdatum);
+			gpart = (GSERIALIZED *)PG_DETOAST_DATUM(gsdatum);
+			if (gserialized_is_empty(gpart))
+			{
+				box2df_set_empty(box2df);
+				return LW_SUCCESS;
+			}
+		}
 	}
 
 	POSTGIS_FREE_IF_COPY_P(gpart, gsdatum);
@@ -868,10 +878,19 @@ Datum gserialized_gist_compress_2d(PG_FUNCTION_ARGS)
 	/* Extract our index key from the GiST entry. */
 	result = gserialized_datum_get_box2df_p(entry_in->key, &bbox_out);
 
-	/* Is the bounding box valid (non-empty, non-infinite)? If not, return input uncompressed. */
-	if ( result == LW_FAILURE )
+	if (result == LW_FAILURE)
+	{
+		/* Treat failure like NULL */
+		POSTGIS_DEBUG(4, "[GIST] leafkey is null");
+		gistentryinit(*entry_out, (Datum) 0, entry_in->rel,
+		              entry_in->page, entry_in->offset, false);
+		POSTGIS_DEBUG(4, "[GIST] returning copy of input");
+		PG_RETURN_POINTER(entry_out);
+	}
+
+	/* Is the bounding box empty? Done! */
+	if (box2df_is_empty(&bbox_out))
 	{
-		box2df_set_empty(&bbox_out);
 		gistentryinit(*entry_out, PointerGetDatum(box2df_copy(&bbox_out)),
 		              entry_in->rel, entry_in->page, entry_in->offset, false);
 
@@ -2050,7 +2069,7 @@ Datum gserialized_gist_picksplit_2d(PG_FUNCTION_ARGS)
 		 * Calculate delta between penalties of join "common entries" to
 		 * different groups.
 		 */
-		for (i = 0; i < commonEntriesCount; i++)
+		for (i = 0; i < (OffsetNumber)commonEntriesCount; i++)
 		{
 			box = (BOX2DF *) DatumGetPointer(entryvec->vector[
 												commonEntries[i].index].key);
@@ -2067,7 +2086,7 @@ Datum gserialized_gist_picksplit_2d(PG_FUNCTION_ARGS)
 		/*
 		 * Distribute "common entries" between groups.
 		 */
-		for (i = 0; i < commonEntriesCount; i++)
+		for (i = 0; i < (OffsetNumber)commonEntriesCount; i++)
 		{
 			float right_penalty, left_penalty;
 			bool place_right = true;
