@@ -85,7 +85,7 @@ static const int16 GeometryStrategies[] = {
 	[ST_OVERLAPS_IDX]               = RTOverlapStrategyNumber,
 	[ST_COVERS_IDX]                 = RTContainsStrategyNumber,
 	[ST_CROSSES_IDX]                = RTOverlapStrategyNumber,
-	[ST_DFULLYWITHIN_IDX]           = RTContainsStrategyNumber,
+	[ST_DFULLYWITHIN_IDX]           = RTContainedByStrategyNumber,
 	[ST_3DDWITHIN_IDX]              = RTOverlapStrategyNumber,
 	[ST_3DDFULLYWITHIN_IDX]         = RTOverlapStrategyNumber,
 	[ST_LINECROSSINGDIRECTION_IDX]  = RTOverlapStrategyNumber,
