@@ -142,15 +142,15 @@ Datum ST_ClusterDBSCAN(PG_FUNCTION_ARGS)
 		/* Validate input parameters */
 		if (tolerance_is_null || tolerance < 0)
 		{
-			lwpgerror("Tolerance must be a positive number", tolerance);
+			lwpgerror("Tolerance must be a positive number, got %g", tolerance);
 			PG_RETURN_NULL();
 		}
 		if (minpoints_is_null || minpoints < 0)
 		{
-			lwpgerror("Minpoints must be a positive number", minpoints);
+			lwpgerror("Minpoints must be a positive number, got %d", minpoints);
 		}
 
-		initGEOS(lwnotice, lwgeom_geos_error);
+		initGEOS(lwpgnotice, lwgeom_geos_error);
 		geoms = lwalloc(ngeoms * sizeof(LWGEOM*));
 		uf = UF_create(ngeoms);
 		for (i = 0; i < ngeoms; i++)
@@ -228,7 +228,7 @@ Datum ST_ClusterWithinWin(PG_FUNCTION_ARGS)
 		/* Validate input parameters */
 		if (tolerance_is_null || tolerance < 0)
 		{
-			lwpgerror("Tolerance must be a positive number", tolerance);
+			lwpgerror("Tolerance must be a positive number, got %g", tolerance);
 			PG_RETURN_NULL();
 		}
 
@@ -371,7 +371,7 @@ Datum ST_ClusterKMeans(PG_FUNCTION_ARGS)
 		int       *r;
 		Datum argdatum;
 
-		/* What is K? If it's NULL or invalid, we can't procede */
+		/* What is K? If it's NULL or invalid, we can't proceed */
 		argdatum = WinGetFuncArgCurrent(winobj, 1, &isnull);
 		k = DatumGetInt32(argdatum);
 		if (isnull || k <= 0)
@@ -465,7 +465,6 @@ Datum ST_ClusterKMeans(PG_FUNCTION_ARGS)
  *
  */
 
-#if POSTGIS_GEOS_VERSION >= 30800
 /*
  * For CoverageUnion and CoverageSimplify, clean up
  * the start of a collection if things fail in mid-stream.
@@ -481,7 +480,6 @@ coverage_destroy_geoms(GEOSGeometry **geoms, uint32 ngeoms)
 			GEOSGeom_destroy(geoms[i]);
 	}
 }
-#endif
 
 #if POSTGIS_GEOS_VERSION >= 31200
 
@@ -654,7 +652,7 @@ coverage_window_calculation(PG_FUNCTION_ARGS, int mode)
 			PG_RETURN_NULL();
 		}
 
-		/* Get the tolerance argument from second postition */
+		/* Get the tolerance argument from second position */
 		d = WinGetFuncArgCurrent(winobj, 1, &isnull);
 		if (!isnull)
 			tolerance = DatumGetFloat8(d);
@@ -668,7 +666,7 @@ coverage_window_calculation(PG_FUNCTION_ARGS, int mode)
 				simplifyBoundary = DatumGetBool(d);
 		}
 
-		initGEOS(lwnotice, lwgeom_geos_error);
+		initGEOS(lwpgnotice, lwgeom_geos_error);
 
 		input = coverage_read_partition_into_collection(winobj, context);
 		if (!input)
@@ -708,7 +706,7 @@ coverage_window_calculation(PG_FUNCTION_ARGS, int mode)
 	if (context->isnull)
 		PG_RETURN_NULL();
 
-	/* Propogate the null entries */
+	/* Propagate the null entries */
 	if (context->idx[curpos] < 0)
 		PG_RETURN_NULL();
 
@@ -795,15 +793,6 @@ Datum ST_CoverageUnion(PG_FUNCTION_ARGS);
 PG_FUNCTION_INFO_V1(ST_CoverageUnion);
 Datum ST_CoverageUnion(PG_FUNCTION_ARGS)
 {
-#if POSTGIS_GEOS_VERSION < 30800
-	lwpgerror("The GEOS version this PostGIS binary "
-		"was compiled against (%d) doesn't support "
-		"'GEOSCoverageUnion' function (3.8.0+ required)",
-		POSTGIS_GEOS_VERSION);
-	PG_RETURN_NULL();
-
-#else /* POSTGIS_GEOS_VERSION >= 30800 */
-
 	GSERIALIZED *result = NULL;
 
 	Datum value;
@@ -867,7 +856,6 @@ Datum ST_CoverageUnion(PG_FUNCTION_ARGS)
 	GEOSGeom_destroy(geos_result);
 
 	PG_RETURN_POINTER(result);
-#endif
 }
 
 
