@@ -267,7 +267,7 @@ rt_pg_options(const char* varname)
 /*  GDAL allowed config options for VSI filesystems */
 /* ---------------------------------------------------------------- */
 
-stringlist_t *vsi_option_stringlist = NULL;
+static stringlist_t *vsi_option_stringlist = NULL;
 
 
 #if POSTGIS_GDAL_VERSION < 23
@@ -646,48 +646,6 @@ rtpg_assignHookEnableOutDBRasters(bool enable, void *extra) {
 }
 
 
-
-/*
-* Machinery for intercepting the system SIGINT
-* handler so we can cancel long-running GDAL operations
-* via the progress handlers.
-*/
-static pqsigfunc coreIntHandler = 0;
-
-#ifdef WIN32
-static void interruptCallback() {
-  if (UNBLOCKED_SIGNAL_QUEUE())
-    pgwin32_dispatch_queued_signals();
-}
-#endif
-
-
-/*
-* This is the interrupt capture for this module.
-* Before handing off the signal to the core, it
-* sets the interrupt flag for currently running
-* functions.
-*/
-static void
-handleInterrupt(int sig)
-{
-	/*
-	* NOTE: printf here would be dangerous, see
-	* https://trac.osgeo.org/postgis/ticket/3644
-	*/
-	// printf("postgis_raster interrupt requested\n"); fflush(stdout);
-
-	/* Request interruption of liblwgeom as well */
-	lwgeom_request_interrupt();
-
-	/* Pass control into the usual core handler */
-	if (coreIntHandler) {
-		(*coreIntHandler)(sig);
-	}
-}
-
-
-
 /* Module load callback */
 void
 _PG_init(void) {
@@ -695,15 +653,6 @@ _PG_init(void) {
 	bool boot_postgis_enable_outdb_rasters = false;
 	MemoryContext old_context;
 
-	/* Set up interrupt capture */
-	coreIntHandler = pqsignal(SIGINT, handleInterrupt);
-
-#ifdef WIN32
- 	GEOS_interruptRegisterCallback(interruptCallback);
- 	lwgeom_register_interrupt_callback(interruptCallback);
-#endif
-
-
 	/*
 	 * Change to context for memory allocation calls like palloc() in the
 	 * extension initialization routine
@@ -867,9 +816,6 @@ _PG_fini(void) {
 
 	elog(NOTICE, "Goodbye from PostGIS Raster %s", POSTGIS_VERSION);
 
-	/* Return SIGINT handling to core */
-	pqsignal(SIGINT, coreIntHandler);
-
 	/* Clean up */
 	pfree(env_postgis_gdal_enabled_drivers);
 	pfree(boot_postgis_gdal_enabled_drivers);
