@@ -1,6 +1,6 @@
 set client_min_messages to WARNING;
 
-\i ../load_topology.sql
+\i :top_builddir/topology/test/load_topology.sql
 \i ../validate_topology.sql
 
 -- clean up
